@@ -123,6 +123,8 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
 
     private CalendarCollection recColl;
     
+    private int readFolderId;
+    
     private static final Log LOG = LogFactory.getLog(FreeBusyResults.class);
     
     /*public FreeBusyResults(final ResultSet rs, final PreparedStatement prep, final Context c, final Connection con, final long range_start, final long range_end) throws OXException {
@@ -297,6 +299,7 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
         if (show_details) {
             if(checkPermissions()) {
                 cdao.setTitle(title);
+                cdao.setParentFolderID(readFolderId);
             }
             final Participants ret = resolveConflictingUserParticipants();
             cdao.setParticipants(ret.getList());
@@ -356,8 +359,10 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
         }
         if (fid > 0) {
             if ( cfo.canReadAllInPublicFolder(fid) ) {
+                readFolderId = fid;
                 return true;
             } else if (owner == uid && cfo.canReadOwnInPublicFolder(fid)) {
+                readFolderId = fid;
                 return true;
             }
         } else {
@@ -367,13 +372,17 @@ public class FreeBusyResults implements SearchIterator<CalendarDataObject> {
                     int o = pfio.getParticipant();
                     int p = pfio.getPrivateFolder();
                     if (cfo.canReadAllInPrivateFolder(p)) {
+                        readFolderId = p;
                         return true;
                     } else if (cfo.canReadAllInSharedFolder(p)) {
+                        readFolderId = p;
                         return true;
                     } else if (o == uid) {
                         if (cfo.canReadOwnInPrivateFolder(p)) {
+                            readFolderId = p;
                             return true;
                         } else if (cfo.canReadOwnInSharedFolder(p)) {
+                            readFolderId = p;
                             return true;
                         }
                     } 
